import request from '@/utils/request'

export function docAssetList(params) {
    return request({
        url: '/asset-tree',
        method: 'get',
        params,
    })
}

export function docProjectList(params) {
    return request({
        url: '/project-tree',
        method: 'get',
        params,
    })
}

export function docLibraryLink(type, params) {
    return request({
        url: '/library-linkage/' + type,
        method: 'get',
        params,
    })
}

export function docLibraryPost(data) {
    return request({
        url: '/library',
        method: 'post',
        data
    })
}

export function docLibraryPatch(library_id, data) {
    return request({
        url: '/library/' + library_id,
        method: 'patch',
        data
    })
}

export function docLibraryList(params) {
    return request({
        url: '/library',
        method: 'get',
        params
    })
}

export function docLibraryDetails(library_id) {
    return request({
        url: '/library/' + library_id,
        method: 'get',
    })
}

export function docLibraryDel(library_id) {
    return request({
        url: '/library/' + library_id,
        method: 'delete',
    })
}

export function docContainerPost(data) {
    return request({
        url: '/container',
        method: 'post',
        data
    })
}

export function docContainerList(params) {
    return request({
        url: '/container',
        method: 'get',
        params
    })
}

export function docContainerPatch(container_id, data) {
    return request({
        url: '/container/' + container_id,
        method: 'patch',
        data
    })
}

export function docContainerDetails(container_id, params) {
    return request({
        url: '/container/' + container_id,
        method: 'get',
        params
    })
}

export function docContainerLinkageList(library_id) {
    return request({
        url: '/container-linkage/' + library_id,
        method: 'get',
    })
}

export function docContainerFolderList(object_type, object_id) {
    return request({
        url: '/folder-tree/' + object_type + '/' + object_id,
        method: 'get',
    })
}

export function docContainerFolderPost(data) {
    return request({
        url: '/folder',
        method: 'post',
        data
    })
}

export function docContainerFolderOpen(params) {
    return request({
        url: '/folder-open',
        method: 'get',
        params
    })
}

export function docContainerFolderDetails(folder) {
    return request({
        url: '/folder/' + folder,
        method: 'get',
    })
}

export function docContainerFolderPatch(folder_id, data) {
    return request({
        url: `/folder/${folder_id}/change-name`,
        method: 'patch',
        data
    })
}

export function docContainerFolderDelete(folder) {
    return request({
        url: '/folder/' + folder,
        method: 'delete',
    })
}

export function docContainerFileDelete(file_id) {
    return request({
        url: '/file/' + file_id + '/destroy',
        method: 'delete',
    })
}

export function folderFileVersionTree(object_type, object_id, params) {
    return request({
        url: '/folder/file-version-tree/' + object_type + '/' + object_id,
        method: 'get',
        params
    })
}

export function folderFileUpload(parameter, onUploadProgress) {
    return request({
        url: '/file/keep-directory-upload',
        method: 'post',
        data: parameter,
        onUploadProgress: onUploadProgress,
        timeout: 0,
    })
}

export function folderFileDownload(data) {
    return request({
        url: '/file/download-zip',
        method: 'post',
        data
    })
}

export function docHistory(id) {
    return request({
        url: `/action/container/history/${id}`,
        method: 'get',
    })
}

export function downAllLatest(object_type,object_id) {
    return request({
        url: `/file/download-all-latest/${object_type}/${object_id}`,
        method: 'get',
    })
}

export function searchF(params) {
    return request({
        url: `/folder/search/folder-file`,
        method: 'get',
        params
    })
}

export function delContainer(id) {
    return request({
        url: `/container/${id}`,
        method: 'delete',
    })
}

export function shareFilePost(data) {
    return request({
        url: `/share-file`,
        method: 'post',
        data
    })
}

export function shareFileGet(uuid) {
    return request({
        url: `/file/download/${uuid}/share-file`,
        method: 'get',
    })
}

export function fileBimView(file_id) {
    return request({
        url: `/file-bim-view/${file_id}`,
        method: 'get',
    })
}

export function attachmentsGet(params) {
    return request({
        url: `/container-attachments`,
        method: 'get',
        params
    })
}

export function containerReport(params) {
    return request({
        url: `/container-report`,
        method: 'get',
        params
    })
}

export function uploadProgress(uuid) {
    return request({
        url: `/file-upload-progress/${uuid}`,
        method: 'get',
    })
}


