import request from '@/utils/request'

export function projectDetails(project_id) {
  return request({
    url: '/project/' + project_id,
    method: 'get',
  })
}

export function linkRequirement(id, data) {
  return request({
    url: `/project/${id}/link-requirement`,
    method: 'patch',
    data,
  })
}

export function projectStart(project_id, data) {
  return request({
    url: `/project/${project_id}/start`,
    method: 'patch',
    data,
  })
}

export function projectClosed(project_id, data) {
  return request({
    url: `/project/${project_id}/closed`,
    method: 'patch',
    data,
  })
}

export function projectPause(project_id, data) {
  return request({
    url: `/project/${project_id}/pause`,
    method: 'patch',
    data,
  })
}

export function projectPostpone(project_id, data) {
  return request({
    url: `/project/${project_id}/postpone`,
    method: 'patch',
    data,
  })
}

export function projectDone(project_id, data) {
  return request({
    url: `/project/${project_id}/done`,
    method: 'patch',
    data,
  })
}

export function unLinkRequirement(id, data) {
  return request({
    url: `/project/${id}/unlink-requirement`,
    method: 'patch',
    data,
  })
}

export function getRequirement(id, params) {
  return request({
    url: `/project/${id}/requirement`,
    method: 'get',
    params,
  })
}

export function linkAssets(id, data) {
  return request({
    url: `/project/${id}/update-link-assets`,
    method: 'patch',
    data,
  })
}

export function projectDynamic(id) {
  return request({
    url: `/project/${id}/dynamic`,
    method: 'get',
  })
}

export function getProjectTree(id) {
  return request({
    url: `/project-tree/${id}`,
    method: 'get',
  })
}

export function taskList(params) {
  return request({
    url: '/task',
    method: 'get',
    params,
  })
}

export function taskPost(data) {
  return request({
    url: '/task',
    method: 'post',
    data
  })
}

export function taskDetails(id) {
  return request({
    url: `/task/${id}`,
    method: 'get',
  })
}

export function taskPatch(id,data) {
  return request({
    url: `/task/${id}`,
    method: 'patch',
    data
  })
}

export function taskBatch(data) {
  return request({
    url: `/task-batch-create`,
    method: 'post',
    data
  })
}

export function taskDel(task_id) {
  return request({
    url: `/task/${task_id}`,
    method: 'delete',
  })
}


export function projectLatestDynamic(id) {
  return request({
    url: `/project/${id}/latest-dynamic`,
    method: 'get',
  })
}

export function autoNaming(id, data) {
  return request({
    url: `/naming-rule/${id}/autoname`,
    method: 'post',
    data
  })
}

export function teamMember(id) {
  return request({
    url: `/team-member/${id}`,
    method: 'get',
  })
}

export function projectLinkRequirementsGroup(project_id) {
  return request({
    url: '/project-link-requirements-group/' + project_id,
    method: 'get'
  })
}

export function taskWait(id, data) {
  return request({
    url: `/task/${id}/wait`,
    method: 'patch',
    data
  })
}

export function taskStart(id, data) {
  return request({
    url: `/task/${id}/start`,
    method: 'patch',
    data
  })
}

export function taskPause(id, data) {
  return request({
    url: `/task/${id}/pause`,
    method: 'patch',
    data
  })
}

export function taskDone(id, data) {
  return request({
    url: `/task/${id}/done`,
    method: 'patch',
    data
  })
}

export function taskClosed(id, data) {
  return request({
    url: `/task/${id}/closed`,
    method: 'patch',
    data
  })
}

export function taskCancel(id, data) {
  return request({
    url: `/task/${id}/cancel`,
    method: 'patch',
    data
  })
}

export function taskAssign(id,data) {
  return request({
    url: `/task/${id}/assign`,
    method: 'patch',
    data
  })
}

export function teamList(id,params) {
  return request({
    url: `/team-member/${id}`,
    method: 'get',
    params
  })
}

export function teamPost(id,data) {
  return request({
    url: `/team-member/${id}/manage`,
    method: 'post',
    data
  })
}

export function teamDel(id) {
  return request({
    url: `/team-member/${id}`,
    method: 'delete'
  })
}

export function kanbanList(project_id, params) {
  return request({
    url: `/project/${project_id}/kanban`,
    method: 'get',
    params
  })
}

export function groupViewList(project_id, params) {
  return request({
    url: `/project/${project_id}/group-view`,
    method: 'get',
    params
  })
}

export function groupGanttList(project_id, params) {
  return request({
    url: `/project/${project_id}/gantt`,
    method: 'get',
    params
  })
}

export function assetTree(project_id) {
  return request({
    url: `/project-asset-tree/${project_id}`,
    method: 'get'
  })
}

export function requirementTree(asset_id) {
  return request({
    url: `/project-requirementGroups-tree/${asset_id}`,
    method: 'get'
  })
}

export function taskExport(params) {
  return request({
    url: `/task-export`,
    method: 'get',
    responseType: 'blob',
    params
  })
}

export function taskImport(data) {
  return request({
    url: `/task-import`,
    method: 'post',
    data
  })
}

export function printKanBan(project_id) {
  return request({
    url: `/project/${project_id}/print-kanban`,
    method: 'get',
  })
}

