import storage from 'store'
import expirePlugin from 'store/plugins/expire'
import { login, getInfo, logout } from '@/api/login'
import { ACCESS_TOKEN, Authorization } from '@/store/mutation-types'
import { welcome } from '@/utils/util'
import { userInfo } from '@/api/headerInfo/index.js'
storage.addPlugin(expirePlugin)
const user = {
  state: {
    token: '',
    name: '',
    welcome: '',
    avatar: '',
    roles: [],
    info: {},
    operation: [],
    theme: localStorage.getItem('navTheme'),
  },

  mutations: {
    SET_TOKEN: (state, token) => {
      state.token = token
    },
    SET_NAME: (state, { name, welcome }) => {
      state.name = name
      state.welcome = welcome
    },
    SET_AVATAR: (state, avatar) => {
      state.avatar = avatar
    },
    SET_ROLES: (state, roles) => {
      state.roles = roles
    },
    SET_INFO: (state, info) => {
      state.info = info
    },
    SET_OPERATION: (state, operation) => {
      state.operation = operation
    },
    SET_THEME: (state, theme) => {
      state.theme = theme
    }
  },

  actions: {
    // 登录
    Login({ commit }, userInfo) {
      return new Promise((resolve, reject) => {
        login(userInfo)
          .then((response) => {
            const result = response.data
            storage.set(ACCESS_TOKEN, result.token, new Date().getTime() + 7 * 24 * 60 * 60 * 1000)
            storage.set(Authorization, result.token)
            commit('SET_TOKEN', result.token)
            resolve()
          })
          .catch((error) => {
            reject(error)
          })
      })
    },

    // 获取用户信息
    GetInfo({ commit }) {
      // return new Promise((resolve, reject) => {
      //   // 请求后端获取用户信息 /api/user/info
      //   getInfo()
      //     .then((response) => {
      //       const { result } = response
      //       if (result.role && result.role.permissions.length > 0) {
      //         const role = { ...result.role }
      //         role.permissions = result.role.permissions.map((permission) => {
      //           const per = {
      //             ...permission,
      //             actionList: permission.actionList,
      //           }
      //           return per
      //         })
      //         role.permissionList = role.permissions.map((permission) => {
      //           return permission.permissionId
      //         })
      //         // 覆盖响应体的 role, 供下游使用
      //         result.role = role

      //         commit('SET_ROLES', role)
      //         commit('SET_INFO', result)
      //         commit('SET_NAME', { name: result.name, welcome: welcome() })
      //         commit('SET_AVATAR', result.avatar)
      //         // 下游
      //         console.log(result,'result mock')
      //         resolve(result)
      //       } else {
      //         reject(new Error('getInfo: roles must be a non-null array !'))
      //       }
      //     })
      //     .catch((error) => {
      //       reject(error)
      //     })
      // })
    },

    getPermissions({ commit, state }) {
      return new Promise((resolve, reject) => {
        userInfo()
          .then((response) => {
            let result = response.data
            const role = { ...result.role }
            role.permissionList = response.data.menus
            // 覆盖响应体的 role, 供下游使用
            result.role = role
            commit('SET_ROLES', role)
            commit('SET_INFO', result)
            commit('SET_NAME', { name: result.description, welcome: welcome() })
            commit('SET_OPERATION', ['asset.index'])
            // // 下游
            resolve(result)

          }).catch((error) => {
            reject(error)
          })
      })
    },

    // 登出
    Logout({ commit, state }) {
      return new Promise((resolve) => {
        logout(state.token)
          .then(() => {
            commit('SET_TOKEN', '')
            commit('SET_ROLES', [])
            storage.remove(ACCESS_TOKEN)
            storage.remove(Authorization)
            resolve()
          })
          .catch((err) => {
            console.log('logout fail:', err)
            commit('SET_TOKEN', '')
            commit('SET_ROLES', [])
            storage.remove(ACCESS_TOKEN)
            storage.remove(Authorization)
            resolve()
          })
          .finally(() => { })
      })
    },
  },
}

export default user
